@@ -27,13 +27,13 @@
 // ----------------------------------------------------------------------------
 // KDE Includes
 
-#include <kapplication.h>
-#include <kglobal.h>
-#include <klocale.h>
+#include <tdeapplication.h>
+#include <tdeglobal.h>
+#include <tdelocale.h>
 #include <kstandarddirs.h>
 #include <kpushbutton.h>
 #include <klineedit.h>
-#include <klistview.h>
+#include <tdelistview.h>
 #include <kcombobox.h>
 #include <kstdguiitem.h>
 #include <kiconloader.h>
@@ -835,9 +835,4 @@ void KFindTransactionDlg::slotSortOptions(void)
   }
   delete dlg;
 }
-
-
-// vim:cin:si:ai:et:ts=2:sw=2:
-
-
 #include "kfindtransactiondlg.moc"
