@@ -26,7 +26,7 @@
 // KDE Includes
 
 #include <kdebug.h>
-#include <klocale.h>
+#include <tdelocale.h>
 #include <kiconloader.h>
 #include <kiconview.h>
 #include <kguiitem.h>
@@ -38,13 +38,13 @@
 #include <kmymoney/mymoneyfile.h>
 #include "kaccountsview.h"
 #include "kmymoneyview.h"
-#include "../widgets/klistviewsearchline.h"
+#include "../widgets/tdelistviewsearchline.h"
 #include "../kmymoneyglobalsettings.h"
 #include "../kmymoney2.h"
 
 
 KMyMoneyAccountIconItem::KMyMoneyAccountIconItem(TQIconView *parent, const MyMoneyAccount& account) :
-  KIconViewItem(parent, account.name()),
+  TDEIconViewItem(parent, account.name()),
   m_account(account),
   m_reconcileFlag(false)
 {
@@ -75,20 +75,20 @@ KAccountsView::KAccountsView(TQWidget *parent, const char *name) :
 {
   // create the searchline widget
   // and insert it into the existing layout
-  m_searchWidget = new KListViewSearchLineWidget(m_accountTree, m_accountTree->parentWidget());
+  m_searchWidget = new TDEListViewSearchLineWidget(m_accountTree, m_accountTree->parentWidget());
   TQVBoxLayout* layout = dynamic_cast<TQVBoxLayout*>(m_accountTree->parentWidget()->layout());
   if(layout) {
     layout->insertWidget(0, m_searchWidget);
   }
 
   // setup icons for collapse and expand button
-  KIconLoader *ic = KGlobal::iconLoader();
+  TDEIconLoader *ic = TDEGlobal::iconLoader();
   KGuiItem collapseGuiItem("",
-                          TQIconSet(ic->loadIcon("viewmag-", KIcon::Small, KIcon::SizeSmall)),
+                          TQIconSet(ic->loadIcon("zoom-out", TDEIcon::Small, TDEIcon::SizeSmall)),
                           TQString(),
                           TQString());
   KGuiItem expandGuiItem("",
-                          TQIconSet(ic->loadIcon("viewmag+", KIcon::Small, KIcon::SizeSmall)),
+                          TQIconSet(ic->loadIcon("zoom-in", TDEIcon::Small, TDEIcon::SizeSmall)),
                           TQString(),
                           TQString());
   m_collapseButton->setGuiItem(collapseGuiItem);
@@ -97,7 +97,7 @@ KAccountsView::KAccountsView(TQWidget *parent, const char *name) :
   for(int i=0; i < MaxViewTabs; ++i)
     m_needReload[i] = false;
 
-  KConfig *config = KGlobal::config();
+  TDEConfig *config = TDEGlobal::config();
   config->setGroup("Last Use Settings");
   m_tab->setCurrentPage(config->readNumEntry("KAccountsView_LastType", 0));
 
@@ -142,7 +142,7 @@ void KAccountsView::slotTabChanged(TQWidget* _tab)
   AccountsViewTab tab = static_cast<AccountsViewTab>(m_tab->indexOf(_tab));
 
   // remember this setting for startup
-  KConfig *config = KGlobal::config();
+  TDEConfig *config = TDEGlobal::config();
   config->setGroup("Last Use Settings");
   config->writeEntry("KAccountsView_LastType", tab);
 
