@@ -28,13 +28,13 @@
 // KDE Includes
 
 #include "kdecompat.h"
-#include <klocale.h>
+#include <tdelocale.h>
 #include <kcombobox.h>
 #include <kpushbutton.h>
-#include <kmessagebox.h>
+#include <tdemessagebox.h>
 #include <kiconloader.h>
-#include <ktoolbar.h>
-#include <ktoolbarbutton.h>
+#include <tdetoolbar.h>
+#include <tdetoolbarbutton.h>
 #include <kpassivepopup.h>
 
 // ----------------------------------------------------------------------------
@@ -58,7 +58,7 @@
 
 #include "../widgets/scheduledtransaction.h"
 
-class KGlobalLedgerView::Private
+class TDEGlobalLedgerView::Private
 {
 public:
   Private();
@@ -134,7 +134,7 @@ bool MousePressFilter::eventFilter(TQObject* o, TQEvent* e)
 }
 
 
-KGlobalLedgerView::Private::Private() :
+TDEGlobalLedgerView::Private::Private() :
   m_mousePressFilter(0),
   m_registerSearchLine(0),
   m_inLoading(false),
@@ -143,9 +143,9 @@ KGlobalLedgerView::Private::Private() :
 {
 }
 
-TQDate KGlobalLedgerView::m_lastPostDate;
+TQDate TDEGlobalLedgerView::m_lastPostDate;
 
-KGlobalLedgerView::KGlobalLedgerView(TQWidget *parent, const char *name )
+TDEGlobalLedgerView::TDEGlobalLedgerView(TQWidget *parent, const char *name )
   : KMyMoneyViewBase(parent, name, i18n("Ledgers")),
   d(new Private),
   m_needReload(false),
@@ -159,9 +159,9 @@ KGlobalLedgerView::KGlobalLedgerView(TQWidget *parent, const char *name )
   m_toolbarFrame = new TQFrame(this);
   TQVBoxLayout* toolbarLayout = new TQVBoxLayout(m_toolbarFrame, 0, 0);
 
-  m_toolbar = new KToolBar(m_toolbarFrame, 0, true);
+  m_toolbar = new TDEToolBar(m_toolbarFrame, 0, true);
   toolbarLayout->addWidget(m_toolbar);
-  m_toolbar->setIconText(KToolBar::IconTextRight);
+  m_toolbar->setIconText(TDEToolBar::IconTextRight);
 
   m_accountComboBox = new KMyMoneyAccountCombo(m_toolbar, "AccountCombo");
   m_toolbar->insertWidget(1, 100, m_accountComboBox);
@@ -170,8 +170,8 @@ KGlobalLedgerView::KGlobalLedgerView(TQWidget *parent, const char *name )
   // the account button at the right of the toolbar
   // I leave the code commented here for a while, so that I see
   // how I can add other  widgets at this point
-  KIconLoader *il = KGlobal::iconLoader();
-  m_toolbar->insertButton(il->loadIcon("document", KIcon::Small, KIcon::SizeSmall),
+  TDEIconLoader *il = TDEGlobal::iconLoader();
+  m_toolbar->insertButton(il->loadIcon("text-x-generic", TDEIcon::Small, TDEIcon::SizeSmall),
                         1,true,i18n("Account"));
   //m_toolbar->setMaximumSize(50,20);
   m_toolbar->alignItemRight(1);
@@ -216,8 +216,8 @@ KGlobalLedgerView::KGlobalLedgerView(TQWidget *parent, const char *name )
   m_buttonFrame = new TQFrame(this);
   TQVBoxLayout* buttonLayout = new TQVBoxLayout(m_buttonFrame, 0, 0);
   layout()->addWidget(m_buttonFrame);
-  m_buttonbar = new KToolBar(m_buttonFrame, 0, true);
-  m_buttonbar->setIconText(KToolBar::IconTextRight);
+  m_buttonbar = new TDEToolBar(m_buttonFrame, 0, true);
+  m_buttonbar->setIconText(TDEToolBar::IconTextRight);
   buttonLayout->addWidget(m_buttonbar);
 
   kmymoney2->action("transaction_new")->plug(m_buttonbar);
@@ -257,18 +257,18 @@ KGlobalLedgerView::KGlobalLedgerView(TQWidget *parent, const char *name )
   d->m_mousePressFilter->addWidget(m_registerFrame);
 }
 
-KGlobalLedgerView::~KGlobalLedgerView()
+TDEGlobalLedgerView::~TDEGlobalLedgerView()
 {
   delete d;
 }
 
-void KGlobalLedgerView::slotAboutToSelectItem(KMyMoneyRegister::RegisterItem* item, bool& okToSelect)
+void TDEGlobalLedgerView::slotAboutToSelectItem(KMyMoneyRegister::RegisterItem* item, bool& okToSelect)
 {
   Q_UNUSED(item);
   emit cancelOrEndEdit(okToSelect);
 }
 
-void KGlobalLedgerView::slotLoadView(void)
+void TDEGlobalLedgerView::slotLoadView(void)
 {
   m_needReload = true;
   if(isVisible()) {
@@ -281,7 +281,7 @@ void KGlobalLedgerView::slotLoadView(void)
   }
 }
 
-void KGlobalLedgerView::clear(void)
+void TDEGlobalLedgerView::clear(void)
 {
   // clear current register contents
   m_register->clear();
@@ -311,7 +311,7 @@ void KGlobalLedgerView::clear(void)
   d->m_precision = 2;
 }
 
-void KGlobalLedgerView::loadView(void)
+void TDEGlobalLedgerView::loadView(void)
 {
   MYMONEYTRACER(tracer);
 
@@ -720,7 +720,7 @@ void KGlobalLedgerView::loadView(void)
   emit accountSelected(m_account);
 }
 
-void KGlobalLedgerView::updateSummaryLine(const TQMap<TQString, MyMoneyMoney>& actBalance, const TQMap<TQString, MyMoneyMoney>& clearedBalance)
+void TDEGlobalLedgerView::updateSummaryLine(const TQMap<TQString, MyMoneyMoney>& actBalance, const TQMap<TQString, MyMoneyMoney>& clearedBalance)
 {
   MyMoneyFile* file = MyMoneyFile::instance();
   m_leftSummaryLabel->show();
@@ -738,7 +738,7 @@ void KGlobalLedgerView::updateSummaryLine(const TQMap<TQString, MyMoneyMoney>& a
     TQDate reconcileDate = m_account.lastReconciliationDate();
 
     if(reconcileDate.isValid()) {
-      m_leftSummaryLabel->setText(i18n("Last reconciled: %1").arg(KGlobal::locale()->formatDate(reconcileDate, true)));
+      m_leftSummaryLabel->setText(i18n("Last reconciled: %1").arg(TDEGlobal::locale()->formatDate(reconcileDate, true)));
     } else {
       m_leftSummaryLabel->setText(i18n("Never reconciled"));
     }
@@ -785,7 +785,7 @@ void KGlobalLedgerView::updateSummaryLine(const TQMap<TQString, MyMoneyMoney>& a
   }
 }
 
-void KGlobalLedgerView::slotUpdateViewPos(void)
+void TDEGlobalLedgerView::slotUpdateViewPos(void)
 {
   m_register->setUpdatesEnabled(true);
 
@@ -800,14 +800,14 @@ void KGlobalLedgerView::slotUpdateViewPos(void)
 }
 
 
-void KGlobalLedgerView::resizeEvent(TQResizeEvent* ev)
+void TDEGlobalLedgerView::resizeEvent(TQResizeEvent* ev)
 {
   m_register->resize(KMyMoneyRegister::DetailColumn);
   m_form->resize(KMyMoneyTransactionForm::ValueColumn1);
   KMyMoneyViewBase::resizeEvent(ev);
 }
 
-void KGlobalLedgerView::loadAccounts(void)
+void TDEGlobalLedgerView::loadAccounts(void)
 {
   MyMoneyFile* file = MyMoneyFile::instance();
 
@@ -847,14 +847,14 @@ void KGlobalLedgerView::loadAccounts(void)
     try {
       d->m_precision = MyMoneyMoney::denomToPrec(m_account.fraction());
     } catch(MyMoneyException *e) {
-      qDebug("Security %s for account %s not found", m_account.currencyId().data(), m_account.name().data());
+      tqDebug("Security %s for account %s not found", m_account.currencyId().data(), m_account.name().data());
       delete e;
       d->m_precision = 2;
     }
   }
 }
 
-void KGlobalLedgerView::selectTransaction(const TQString& id)
+void TDEGlobalLedgerView::selectTransaction(const TQString& id)
 {
   if(!id.isEmpty()) {
     KMyMoneyRegister::RegisterItem* p = m_register->lastItem();
@@ -872,7 +872,7 @@ void KGlobalLedgerView::selectTransaction(const TQString& id)
   }
 }
 
-void KGlobalLedgerView::slotSelectAllTransactions(void)
+void TDEGlobalLedgerView::slotSelectAllTransactions(void)
 {
   KMyMoneyRegister::RegisterItem* p = m_register->firstItem();
   while(p) {
@@ -891,7 +891,7 @@ void KGlobalLedgerView::slotSelectAllTransactions(void)
   emit transactionsSelected(list);
 }
 
-void KGlobalLedgerView::slotSetReconcileAccount(const MyMoneyAccount& acc, const TQDate& reconciliationDate, const MyMoneyMoney& endingBalance)
+void TDEGlobalLedgerView::slotSetReconcileAccount(const MyMoneyAccount& acc, const TQDate& reconciliationDate, const MyMoneyMoney& endingBalance)
 {
   if(d->m_reconciliationAccount != acc.id()) {
     // make sure the account is selected
@@ -920,12 +920,12 @@ void KGlobalLedgerView::slotSetReconcileAccount(const MyMoneyAccount& acc, const
   }
 }
 
-bool KGlobalLedgerView::isReconciliationAccount(void) const
+bool TDEGlobalLedgerView::isReconciliationAccount(void) const
 {
   return m_account.id() == d->m_reconciliationAccount;
 }
 
-bool KGlobalLedgerView::slotSelectAccount(const MyMoneyObject& obj)
+bool TDEGlobalLedgerView::slotSelectAccount(const MyMoneyObject& obj)
 {
   if(typeid(obj) != typeid(MyMoneyAccount))
     return false;
@@ -940,7 +940,7 @@ bool KGlobalLedgerView::slotSelectAccount(const MyMoneyObject& obj)
   return rc;
 }
 
-bool KGlobalLedgerView::slotSelectAccount(const TQString& id, const TQString& transactionId)
+bool TDEGlobalLedgerView::slotSelectAccount(const TQString& id, const TQString& transactionId)
 {
   bool    rc = true;
 
@@ -956,7 +956,7 @@ bool KGlobalLedgerView::slotSelectAccount(const TQString& id, const TQString& tr
         m_newAccountLoaded = true;
         slotLoadView();
       } catch(MyMoneyException* e) {
-        qDebug("Unable to retrieve account %s", id.data());
+        tqDebug("Unable to retrieve account %s", id.data());
         delete e;
         rc = false;
       }
@@ -970,7 +970,7 @@ bool KGlobalLedgerView::slotSelectAccount(const TQString& id, const TQString& tr
   return rc;
 }
 
-void KGlobalLedgerView::slotNewTransaction(KMyMoneyRegister::Action id)
+void TDEGlobalLedgerView::slotNewTransaction(KMyMoneyRegister::Action id)
 {
   if(!m_inEditMode) {
     d->m_action = id;
@@ -978,12 +978,12 @@ void KGlobalLedgerView::slotNewTransaction(KMyMoneyRegister::Action id)
   }
 }
 
-void KGlobalLedgerView::slotNewTransaction(void)
+void TDEGlobalLedgerView::slotNewTransaction(void)
 {
   slotNewTransaction(KMyMoneyRegister::ActionNone);
 }
 
-void KGlobalLedgerView::setupDefaultAction(void)
+void TDEGlobalLedgerView::setupDefaultAction(void)
 {
   switch(m_account.accountType()) {
     // TODO if we want a different action for different account types
@@ -994,7 +994,7 @@ void KGlobalLedgerView::setupDefaultAction(void)
   }
 }
 
-bool KGlobalLedgerView::selectEmptyTransaction(void)
+bool TDEGlobalLedgerView::selectEmptyTransaction(void)
 {
   bool rc = false;
 
@@ -1026,7 +1026,7 @@ bool KGlobalLedgerView::selectEmptyTransaction(void)
   return rc;
 }
 
-TransactionEditor* KGlobalLedgerView::startEdit(const KMyMoneyRegister::SelectedTransactions& list)
+TransactionEditor* TDEGlobalLedgerView::startEdit(const KMyMoneyRegister::SelectedTransactions& list)
 {
   // we use the warnlevel to keep track, if we have to warn the
   // user that some or all splits have been reconciled or if the
@@ -1168,7 +1168,7 @@ TransactionEditor* KGlobalLedgerView::startEdit(const KMyMoneyRegister::Selected
   return editor;
 }
 
-void KGlobalLedgerView::slotLeaveEditMode(const KMyMoneyRegister::SelectedTransactions& list)
+void TDEGlobalLedgerView::slotLeaveEditMode(const KMyMoneyRegister::SelectedTransactions& list)
 {
   m_inEditMode = false;
   tqApp->removeEventFilter(d->m_mousePressFilter);
@@ -1203,21 +1203,21 @@ void KGlobalLedgerView::slotLeaveEditMode(const KMyMoneyRegister::SelectedTransa
   m_register->setFocus();
 }
 
-bool KGlobalLedgerView::focusNextPrevChild(bool next)
+bool TDEGlobalLedgerView::focusNextPrevChild(bool next)
 {
   bool  rc = false;
 
-  // qDebug("KGlobalLedgerView::focusNextPrevChild(editmode=%s)", m_inEditMode ? "true" : "false");
+  // tqDebug("TDEGlobalLedgerView::focusNextPrevChild(editmode=%s)", m_inEditMode ? "true" : "false");
   if(m_inEditMode) {
     TQWidget *w = 0;
     TQWidget *currentWidget;
 
     w = tqApp->focusWidget();
     while(w && m_tabOrderWidgets.find(w) == -1) {
-      // qDebug("'%s' not in list, use parent", w->className());
+      // tqDebug("'%s' not in list, use parent", w->className());
       w = w->parentWidget();
     }
-    // if(w) qDebug("tab order is at '%s'", w->className());
+    // if(w) tqDebug("tab order is at '%s'", w->className());
     currentWidget = m_tabOrderWidgets.current();
     w = next ? m_tabOrderWidgets.next() : m_tabOrderWidgets.prev();
 
@@ -1229,7 +1229,7 @@ bool KGlobalLedgerView::focusNextPrevChild(bool next)
       if(w != currentWidget
       && ((w->focusPolicy() & TQ_TabFocus) == TQ_TabFocus)
       && w->isVisible() && w->isEnabled()) {
-        // qDebug("Selecting '%s' as focus", w->className());
+        // tqDebug("Selecting '%s' as focus", w->className());
         w->setFocus();
         rc = true;
         break;
@@ -1244,7 +1244,7 @@ bool KGlobalLedgerView::focusNextPrevChild(bool next)
 }
 
 
-void KGlobalLedgerView::show(void)
+void TDEGlobalLedgerView::show(void)
 {
   if(m_needReload) {
     if(!m_inEditMode) {
@@ -1263,21 +1263,21 @@ void KGlobalLedgerView::show(void)
   KMyMoneyViewBase::show();
 }
 
-bool KGlobalLedgerView::eventFilter(TQObject* o, TQEvent* e)
+bool TDEGlobalLedgerView::eventFilter(TQObject* o, TQEvent* e)
 {
   bool rc = false;
 
   if(e->type() == TQEvent::KeyPress) {
     TQKeyEvent *k = TQT_TQKEYEVENT(e);
     if(m_inEditMode) {
-      // qDebug("object = %s, key = %d", o->className(), k->key());
+      // tqDebug("object = %s, key = %d", o->className(), k->key());
       if(TQT_BASE_OBJECT(o) == TQT_BASE_OBJECT(m_register)) {
         // we hide all key press events from the register
         // while editing a transaction
         rc = true;
       }
     } else {
-      // qDebug("object = %s, key = %d", o->className(), k->key());
+      // tqDebug("object = %s, key = %d", o->className(), k->key());
       if(TQT_BASE_OBJECT(o) == TQT_BASE_OBJECT(m_register)) {
         if((k->state() & TQt::KeyButtonMask) == 0) {
           switch(k->key()) {
@@ -1298,7 +1298,7 @@ bool KGlobalLedgerView::eventFilter(TQObject* o, TQEvent* e)
   return rc;
 }
 
-void KGlobalLedgerView::slotSortOptions(void)
+void TDEGlobalLedgerView::slotSortOptions(void)
 {
   KSortOptionDlg* dlg = new KSortOptionDlg(this);
 
@@ -1333,7 +1333,7 @@ void KGlobalLedgerView::slotSortOptions(void)
         MyMoneyFile::instance()->modifyAccount(m_account);
         ft.commit();
       } catch(MyMoneyException* e) {
-        qDebug("Unable to update sort order for account '%s': %s", m_account.name().latin1(), e->what().latin1());
+        tqDebug("Unable to update sort order for account '%s': %s", m_account.name().latin1(), e->what().latin1());
         delete e;
       }
     }
@@ -1341,19 +1341,19 @@ void KGlobalLedgerView::slotSortOptions(void)
   delete dlg;
 }
 
-void KGlobalLedgerView::slotToggleTransactionMark(KMyMoneyRegister::Transaction* /* t */)
+void TDEGlobalLedgerView::slotToggleTransactionMark(KMyMoneyRegister::Transaction* /* t */)
 {
   if(!m_inEditMode) {
     emit toggleReconciliationFlag();
   }
 }
 
-void KGlobalLedgerView::slotKeepPostDate(const TQDate& date)
+void TDEGlobalLedgerView::slotKeepPostDate(const TQDate& date)
 {
   m_lastPostDate = date;
 }
 
-bool KGlobalLedgerView::canCreateTransactions(TQString& tooltip) const
+bool TDEGlobalLedgerView::canCreateTransactions(TQString& tooltip) const
 {
   bool rc = true;
   if(m_account.id().isEmpty()) {
@@ -1372,7 +1372,7 @@ bool KGlobalLedgerView::canCreateTransactions(TQString& tooltip) const
   return rc;
 }
 
-bool KGlobalLedgerView::canProcessTransactions(const KMyMoneyRegister::SelectedTransactions& list, TQString& tooltip) const
+bool TDEGlobalLedgerView::canProcessTransactions(const KMyMoneyRegister::SelectedTransactions& list, TQString& tooltip) const
 {
   if(m_register->focusItem() == 0)
     return false;
@@ -1384,17 +1384,17 @@ bool KGlobalLedgerView::canProcessTransactions(const KMyMoneyRegister::SelectedT
   return list.count() > 0;
 }
 
-bool KGlobalLedgerView::canModifyTransactions(const KMyMoneyRegister::SelectedTransactions& list, TQString& tooltip) const
+bool TDEGlobalLedgerView::canModifyTransactions(const KMyMoneyRegister::SelectedTransactions& list, TQString& tooltip) const
 {
   return canProcessTransactions(list,tooltip) && list.canModify();
 }
 
-bool KGlobalLedgerView::canDuplicateTransactions(const KMyMoneyRegister::SelectedTransactions& list, TQString& tooltip) const
+bool TDEGlobalLedgerView::canDuplicateTransactions(const KMyMoneyRegister::SelectedTransactions& list, TQString& tooltip) const
 {
   return canProcessTransactions(list,tooltip) && list.canDuplicate();
 }
 
-bool KGlobalLedgerView::canEditTransactions(const KMyMoneyRegister::SelectedTransactions& list, TQString& tooltip) const
+bool TDEGlobalLedgerView::canEditTransactions(const KMyMoneyRegister::SelectedTransactions& list, TQString& tooltip) const
 {
   // check if we can edit the list of transactions. We can edit, if
   //
